@@ -128,44 +128,44 @@ LDAPController::LDAPController(TQWidget *parent, const char *name, const TQStrin
 	setRootOnlyMsg(i18n("<b>LDAP controller settings take effect system wide, and require administrator access to modify</b><br>To alter the system's realm controller settings, click on the \"Administrator Mode\" button below."));
 	setUseRootOnlyMsg(true);
 
-	connect(m_base->systemEnableSupport, TQT_SIGNAL(clicked()), this, TQT_SLOT(changed()));
-	connect(m_base->systemEnableSupport, TQT_SIGNAL(clicked()), this, TQT_SLOT(processLockouts()));
-	connect(m_base->systemRole, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(systemRoleChanged()));
+	connect(m_base->systemEnableSupport, TQ_SIGNAL(clicked()), this, TQ_SLOT(changed()));
+	connect(m_base->systemEnableSupport, TQ_SIGNAL(clicked()), this, TQ_SLOT(processLockouts()));
+	connect(m_base->systemRole, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(systemRoleChanged()));
 
-	connect(m_base->caSetMaster, TQT_SIGNAL(clicked()), this, TQT_SLOT(btncaSetMaster()));
+	connect(m_base->caSetMaster, TQ_SIGNAL(clicked()), this, TQ_SLOT(btncaSetMaster()));
 
-	connect(m_base->caRegenerate, TQT_SIGNAL(clicked()), this, TQT_SLOT(btncaRegenerate()));
-	connect(m_base->caExportKey, TQT_SIGNAL(clicked()), this, TQT_SLOT(btncaExportKey()));
-	connect(m_base->caExportCert, TQT_SIGNAL(clicked()), this, TQT_SLOT(btncaExportCert()));
+	connect(m_base->caRegenerate, TQ_SIGNAL(clicked()), this, TQ_SLOT(btncaRegenerate()));
+	connect(m_base->caExportKey, TQ_SIGNAL(clicked()), this, TQ_SLOT(btncaExportKey()));
+	connect(m_base->caExportCert, TQ_SIGNAL(clicked()), this, TQ_SLOT(btncaExportCert()));
 
-	connect(m_base->krbRegenerate, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnkrbRegenerate()));
-	connect(m_base->krbExportKey, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnkrbExportKey()));
-	connect(m_base->krbExportCert, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnkrbExportCert()));
+	connect(m_base->krbRegenerate, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnkrbRegenerate()));
+	connect(m_base->krbExportKey, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnkrbExportKey()));
+	connect(m_base->krbExportCert, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnkrbExportCert()));
 
-	connect(m_base->ldapRegenerate, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnldapRegenerate()));
-	connect(m_base->ldapExportKey, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnldapExportKey()));
-	connect(m_base->ldapExportCert, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnldapExportCert()));
+	connect(m_base->ldapRegenerate, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnldapRegenerate()));
+	connect(m_base->ldapExportKey, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnldapExportKey()));
+	connect(m_base->ldapExportCert, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnldapExportCert()));
 
-	connect(m_base->crlRegenerate, TQT_SIGNAL(clicked()), this, TQT_SLOT(btncrlRegenerate()));
+	connect(m_base->crlRegenerate, TQ_SIGNAL(clicked()), this, TQ_SLOT(btncrlRegenerate()));
 
-	connect(m_base->btnChangeLDAPRootPassword, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnChangeLDAPRootPassword()));
-	connect(m_base->btnChangeRealmAdminPassword, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnChangeRealmAdminPassword()));
+	connect(m_base->btnChangeLDAPRootPassword, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnChangeLDAPRootPassword()));
+	connect(m_base->btnChangeRealmAdminPassword, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnChangeRealmAdminPassword()));
 
-	connect(&m_certRefreshTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateCertDisplay()));
+	connect(&m_certRefreshTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(updateCertDisplay()));
 
-	connect(m_base->advancedEnableMultiMasterReplication, TQT_SIGNAL(clicked()), this, TQT_SLOT(changed()));
+	connect(m_base->advancedEnableMultiMasterReplication, TQ_SIGNAL(clicked()), this, TQ_SLOT(changed()));
 
-	connect(m_base->btnAddMultiMasterReplicationMapping, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnAddMultiMasterReplicationMapping()));
-	connect(m_base->btnEditMultiMasterReplicationMapping, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnEditMultiMasterReplicationMapping()));
-	connect(m_base->btnRemoveMultiMasterReplicationMapping, TQT_SIGNAL(clicked()), this, TQT_SLOT(btnRemoveMultiMasterReplicationMapping()));
+	connect(m_base->btnAddMultiMasterReplicationMapping, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnAddMultiMasterReplicationMapping()));
+	connect(m_base->btnEditMultiMasterReplicationMapping, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnEditMultiMasterReplicationMapping()));
+	connect(m_base->btnRemoveMultiMasterReplicationMapping, TQ_SIGNAL(clicked()), this, TQ_SLOT(btnRemoveMultiMasterReplicationMapping()));
 
-	connect(m_base->multiMasterReplicationMappings, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(multiMasterReplicationHighlighted()));
-	connect(m_base->multiMasterReplicationMappings, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(modifySelectedMultiMasterReplication()));
+	connect(m_base->multiMasterReplicationMappings, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(multiMasterReplicationHighlighted()));
+	connect(m_base->multiMasterReplicationMappings, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(modifySelectedMultiMasterReplication()));
 
-	connect(m_base->advancedCaCertExpiry, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(caCertExpiryChanged()));
-	connect(m_base->advancedCaCrlExpiry, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(caCrlExpiryChanged()));
-	connect(m_base->advancedKerberosCertExpiry, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(kerberosCertExpiryChanged()));
-	connect(m_base->advancedLdapCertExpiry, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(ldapCertExpiryChanged()));
+	connect(m_base->advancedCaCertExpiry, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(caCertExpiryChanged()));
+	connect(m_base->advancedCaCrlExpiry, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(caCrlExpiryChanged()));
+	connect(m_base->advancedKerberosCertExpiry, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(kerberosCertExpiryChanged()));
+	connect(m_base->advancedLdapCertExpiry, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(ldapCertExpiryChanged()));
 
 	m_fqdn = LDAPManager::getMachineFQDN();
 	m_roleFullyConfigured = true;
@@ -682,7 +682,7 @@ void LDAPController::btncaExportKey() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.key|Private Key (*.key)", this, i18n("Select a location to save a copy of the private key..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
@@ -691,7 +691,7 @@ void LDAPController::btncaExportCert() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.pem|PKI Certificate Files (*.pem)", this, i18n("Select a location to save a copy of the certificate..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
@@ -709,7 +709,7 @@ void LDAPController::btnkrbExportKey() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.key|Private Key (*.key)", this, i18n("Select a location to save a copy of the private key..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
@@ -721,7 +721,7 @@ void LDAPController::btnkrbExportCert() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.pem|PKI Certificate Files (*.pem)", this, i18n("Select a location to save a copy of the certificate..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
@@ -749,7 +749,7 @@ void LDAPController::btnldapExportKey() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.key|Private Key (*.key)", this, i18n("Select a location to save a copy of the private key..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
@@ -761,7 +761,7 @@ void LDAPController::btnldapExportCert() {
 	KURL dest = KFileDialog::getSaveURL(TQString::null, "*.pem|PKI Certificate Files (*.pem)", this, i18n("Select a location to save a copy of the certificate..."));
 	if (!dest.isEmpty()) {
 		TDEIO::CopyJob* job = TDEIO::copy(src, dest, true);
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotCertCopyResult(TDEIO::Job*)));
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotCertCopyResult(TDEIO::Job*)));
 	}
 }
 
